
.. image:: https://badge.fury.io/py/galaxy-release-utils.svg
   :target: https://pypi.org/project/galaxy-release-utils/



Overview
--------

Scripts to create new Galaxy_ releases.

* Code: https://github.com/galaxyproject/galaxy

.. _Galaxy: http://galaxyproject.org/
